@@ -492,6 +492,8 @@ class App_qt(App_base):
                     except Exception:
                         pass  # tough luck
 
+                setattr(theApp, "exec", theApp.exec_)
+
                 # Call init function (in case the user overloaded it)
                 theApp.__init__(*args, **kwargs)
 
@@ -532,7 +534,7 @@ class App_qt(App_base):
                 timer.singleShot(0, reEnableSysExit)
 
             def quit(self, *args, **kwargs):
-                """ Do not quit if Qt app quits. """
+                """Do not quit if Qt app quits."""
                 pass
 
         # Instantiate application object
@@ -567,19 +569,39 @@ class App_qt(App_base):
         # Create timer
         timer = self._timer = self._QtCore.QTimer()
         timer.setSingleShot(False)
-        timer.setInterval(0.05 * 1000)  # ms
+        timer.setInterval(int(0.05 * 1000))  # ms
         timer.timeout.connect(repl_callback)
         timer.start()
 
         # Enter Qt mainloop
         # self._QtGui.real_QApplication.exec_(self.app)
-        self._QtGui.real_QApplication.exec_()
+        exec_ = getattr(self._QtGui.real_QApplication, "exec", None)
+        if exec_ is None:
+            exec_ = self._QtGui.real_QApplication.exec_
+        try:
+            try_again = False
+            exec_(self.app)
+        except TypeError:
+            try_again = True
+        if try_again:
+            exec_()
 
     def quit(self):
         # A nicer way to quit
         self._QtGui.real_QApplication.quit()
 
 
+class App_pyqt6(App_qt):
+    """Hijack the PyQt6 mainloop."""
+
+    def importCoreAndGui(self):
+        # Try importing qt
+        import PyQt6  # noqa
+        from PyQt6 import QtGui, QtCore, QtWidgets  # noqa
+
+        return QtWidgets, QtCore  # QApp sits on QtWidgets
+
+
 class App_pyqt5(App_qt):
     """Hijack the PyQt5 mainloop."""
 
@@ -602,6 +624,17 @@ class App_pyqt4(App_qt):
         return QtGui, QtCore
 
 
+class App_pyside6(App_qt):
+    """Hijack the PySide6 mainloop."""
+
+    def importCoreAndGui(self):
+        # Try importing qt
+        import PySide6  # noqa
+        from PySide6 import QtGui, QtCore, QtWidgets  # noqa
+
+        return QtWidgets, QtCore  # QApp sits on QtWidgets
+
+
 class App_pyside2(App_qt):
     """Hijack the PySide2 mainloop."""
 
